@@ -1,17 +1,14 @@
 use bevy::prelude::*;
 
-use crate::{MouseMotion, MouseTrackingSystem};
-
 /// Plugin that tracks mouse motion.
 pub struct MouseMotionPlugin;
 
+pub use bevy::input::mouse::MouseMotion;
+
 impl bevy::app::Plugin for MouseMotionPlugin {
     fn build(&self, app: &mut bevy::app::App) {
         app.insert_resource(MouseMotion { delta: Vec2::ZERO });
-        app.add_system_to_stage(
-            CoreStage::First,
-            update_mouse_motion.label(MouseTrackingSystem::Motion),
-        );
+        app.add_system_to_stage(CoreStage::First, update_mouse_motion);
     }
 }
 
